@@ -231,7 +231,7 @@ function(x, i, j, ..., addFinalizer = NA)
 
 
 xmlValue.XMLInternalNode =
-function(x, ignoreComments = FALSE, recursive = TRUE, encoding = getEncoding(x)) #CE_NATIVE)
+function(x, ignoreComments = FALSE, recursive = TRUE, encoding = getEncoding(x), trim = FALSE) #CE_NATIVE)
 {
 
   encoding = if(is.integer(encoding)) 
@@ -251,7 +251,11 @@ function(x, ignoreComments = FALSE, recursive = TRUE, encoding = getEncoding(x))
       return(character())
    }
   
-  .Call("R_xmlNodeValue", x, NULL, encoding, PACKAGE = "XML") # 2nd argument ignored.
+  ans = .Call("R_xmlNodeValue", x, NULL, encoding, PACKAGE = "XML") # 2nd argument ignored.
+  if(trim)
+     trim(ans)
+  else
+     ans
 }
 
 setS3Method("xmlValue", "XMLInternalNode")
@@ -311,6 +315,18 @@ function(X, FUN, ..., omitNodeTypes = c("XMLXIncludeStartNode", "XMLXIncludeEndN
 }  
 
 
+xmlSApply.XMLNodeSet =
+function(X, FUN, ..., omitNodeTypes = c("XMLXIncludeStartNode", "XMLXIncludeEndNode"), addFinalizer = NA)
+{
+  sapply(X, FUN, ...)
+}
+
+xmlApply.XMLNodeSet =
+function(X, FUN, ..., omitNodeTypes = c("XMLXIncludeStartNode", "XMLXIncludeEndNode"), addFinalizer = NA)
+{
+  lapply(X, FUN, ...)
+}
+
 getChildrenStrings =
 function(node, encoding = getEncoding(node), asVector = TRUE, len = xmlSize(node),
           addNames = TRUE)
@@ -429,6 +445,7 @@ function(dtd = "", namespaces = NULL, addFinalizer = TRUE, name = character(), n
 
   if(length(node)) {
     if(is.character(node))
+	## FIXME: there is no visible 'doc' here
        newXMLTextNode(node, addFinalizer = FALSE, parent = doc)
     else
        addChildren(ans, node)
@@ -963,7 +980,7 @@ function(x, i, j, ..., value)
      i = k
    }
 
-   replace =  (i <= xmlSize(x))
+   replace = !is.na(i) & (i <= xmlSize(x))
 
    if(replace) 
      replaceNodes(xmlChildren(x)[[i]], value)
